@@ -3,7 +3,7 @@ package WebService::Async::UserAgent;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 =head1 NAME
 
@@ -11,7 +11,7 @@ WebService::Async::UserAgent - common API for making HTTP requests to webservice
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -57,15 +57,19 @@ sub timeout { 60 }
 
 sub request { ... }
 
-sub get {
+sub GET {
 	my ($self, $uri) = @_;
 	$uri = URI->new($uri) unless ref $uri;
 	my $req = HTTP::Request->new(
 		GET => $uri
 	);
+	$req->header(host => $uri->host);
 	$self->request($req)
 }
 
+# Back-compat
+*get = \&GET;
+
 sub user_agent { $_[0]->{user_agent} //= "Mozilla/5.0 (Perl) " . (ref $_[0] || $_[0]) }
 
 sub ssl_args { () }
