@@ -1,5 +1,5 @@
 package WebService::Async::UserAgent::NaHTTP;
-$WebService::Async::UserAgent::NaHTTP::VERSION = '0.002';
+$WebService::Async::UserAgent::NaHTTP::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ WebService::Async::UserAgent::NaHTTP - make requests using L<Net::Async::HTTP>
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
@@ -34,15 +34,21 @@ response content on success, or the failure reason on failure.
 =cut
 
 sub request {
-	my $self = shift;
-	my $req = shift;
-	my ($host, $port) = split /:/, '' . $req->uri->host_port;
-	my $ssl = $req->uri->scheme eq 'https';
+	my ($self, $req, %args) = @_;
+	my $host = delete $args{host};
+	my $port = delete $args{port};
+	unless(defined($host) && defined($port)) {
+		my ($h, $p) = split /:/, '' . $req->uri->host_port;
+		$host //= $h;
+		$port //= $p;
+	}
+	my $ssl = delete($args{ssl}) // ($req->uri->scheme eq 'https');
 	$self->ua->do_request(
 		request => $req,
 		host    => $host,
 		port    => $port || ($ssl ? 443 : 80),
 		SSL     => ($ssl ? 1 : 0),
+		%args,
 	)->transform(
 		done => sub {
 			shift->decoded_content
